@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # MinIO Python Library for Amazon S3 Compatible Cloud Storage,
-# (C) 2015,2016 MinIO, Inc.
+# (C) 2015-2020 MinIO, Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,39 +14,38 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from minio.compat import _is_py3
-from minio.fold_case_dict import FoldCaseDict
+from http import client as httplib
 
-if _is_py3:
-    import http.client as httplib
-else:
-    import httplib
-
-from nose.tools import eq_
 
 class MockResponse(object):
-    def __init__(self, method, url, headers, status_code, response_headers=None,
-                 content=None):
+    def __init__(self, method, url, headers, status_code,
+                 response_headers=None, content=None):
         self.method = method
         self.url = url
-        self.request_headers = FoldCaseDict()
-        for header in headers:
-            self.request_headers[header] = headers[header]
+        self.request_headers = {
+            key.lower(): value for key, value in headers.items()
+        }
         self.status = status_code
-        self.headers = response_headers
+        self.headers = {
+            key.lower(): value for key, value in (
+                response_headers or {}).items()
+        }
         self.data = content
         if content is None:
             self.reason = httplib.responses[status_code]
 
     # noinspection PyUnusedLocal
-    def read(self, amt=1024):
+    def read(self, *args, **kwargs):
         return self.data
 
     def mock_verify(self, method, url, headers):
-        eq_(self.method, method)
-        eq_(self.url, url)
-        for header in headers:
-            eq_(self.request_headers[header], headers[header])
+        assert self.method == method
+        assert self.url == url
+        headers = {
+            key.lower(): value for key, value in headers.items()
+        }
+        for header in self.request_headers:
+            assert self.request_headers[header] == headers[header]
 
     # noinspection PyUnusedLocal
     def stream(self, chunk_size=1, decode_unicode=False):
@@ -58,6 +57,14 @@ class MockResponse(object):
     def release_conn(self):
         return
 
+    def getheader(self, key, value=None):
+        return self.headers.get(key, value) if self.headers else value
+
+    def __getitem__(self, key):
+        if key == "status":
+            return self.status
+
+
 class MockConnection(object):
     def __init__(self):
         self.requests = []
@@ -67,11 +74,13 @@ class MockConnection(object):
 
     # noinspection PyUnusedLocal
     def request(self, method, url, headers, redirect=False):
-        return_request = self.requests.pop(0)
+        # only pop off matching requests
+        return_request = self.requests[0]
         return_request.mock_verify(method, url, headers)
-        return return_request
+        return self.requests.pop(0)
 
     # noinspection PyRedeclaration,PyUnusedLocal,PyUnusedLocal
-    def urlopen(self, method, url, headers, preload_content=False, body=None,
-                redirect=False):
+
+    def urlopen(self, method, url, headers={}, preload_content=False,
+                body=None, redirect=False):
         return self.request(method, url, headers)
